import { jsx } from '@emotion/core';
import _pt from 'prop-types';
import { visuallyHiddenCss } from '../../stylesheets/a11y.esm.js';

const defaultGetProgressColor = (theme, progression) => {
  if (progression < 33) {
    return theme.colors.red[50];
  }

  if (progression < 66) {
    return theme.colors.orange[50];
  }

  return theme.colors.green[50];
};

const progressCss = (theme, progression, getProgressColor) => ({
  display: "block",
  width: "100%",
  height: "6px",
  borderRadius: theme.radii[2],
  position: "relative",
  "&:before": {
    content: "''",
    width: `${progression}%`,
    height: "6px",
    position: "absolute",
    backgroundColor: getProgressColor(theme, progression),
    borderRadius: theme.radii[2]
  },
  background: theme.colors.grey[20]
});

const ProgressBar = ({
  max,
  min = 0,
  value,
  getProgressColor = defaultGetProgressColor,
  ...props
}) => {
  const normalizedValue = value > max ? max : value < min ? min : value;
  const progression = normalizedValue / max * 100;
  return jsx("div", {
    "aria-describedby": props["aria-describedby"],
    role: "progressbar",
    "aria-valuenow": normalizedValue,
    "aria-valuemin": min,
    "aria-valuemax": max,
    css: theme => progressCss(theme, progression, getProgressColor)
  }, jsx("span", {
    css: visuallyHiddenCss
  }, normalizedValue, "/", max));
};
ProgressBar.propTypes = {
  max: _pt.number.isRequired,
  min: _pt.number,
  value: _pt.number.isRequired,
  "aria-describedby": _pt.string.isRequired,
  getProgressColor: _pt.func
};

export { ProgressBar };
//# sourceMappingURL=ProgressBar.esm.js.map
